===============================
caixabreak
===============================


.. image:: https://img.shields.io/pypi/v/caixabreak.svg
        :target: https://pypi.python.org/pypi/caixabreak

.. image:: https://img.shields.io/travis/kintoandar/caixabreak.svg
        :target: https://travis-ci.org/kintoandar/caixabreak

.. image:: https://readthedocs.org/projects/caixabreak/badge/?version=latest
        :target: https://caixabreak.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/kintoandar/cookiecutter-django/shield.svg
     :target: https://pyup.io/repos/github/kintoandar/caixabreak/
     :alt: Updates


Extracts data from CGD - Caixa Break management interface


* Free software: MIT license
* Documentation: https://caixabreak.readthedocs.io.


Features
--------

* TODO

Credits
---------

* TODO
